@@ -4,7 +4,7 @@ Main interface for codestar-notifications service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_codestar_notifications import (
         Client,
         CodeStarNotificationsClient,
@@ -13,10 +13,8 @@ Usage::
         ListTargetsPaginator,
     )
 
-    session = boto3.Session()
-
-    client: CodeStarNotificationsClient = boto3.client("codestar-notifications")
-    session_client: CodeStarNotificationsClient = session.client("codestar-notifications")
+    session = Session()
+    client: CodeStarNotificationsClient = session.client("codestar-notifications")
 
     list_event_types_paginator: ListEventTypesPaginator = client.get_paginator("list_event_types")
     list_notification_rules_paginator: ListNotificationRulesPaginator = client.get_paginator("list_notification_rules")
