@@ -9,8 +9,8 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.CodeStarNotifications 1.25.0\nVersion:         1.25.0\nBuilder"
-        " version: 7.11.10\nDocs:           "
+        "Type annotations for boto3.CodeStarNotifications 1.26.0\nVersion:        "
+        " 1.26.0.post1\nBuilder version: 7.11.10\nDocs:           "
         " https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications//\nBoto3"
         " docs:     "
         " https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codestar-notifications.html#CodeStarNotifications\nOther"
@@ -23,7 +23,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.25.0")
+    print("1.26.0.post1")
 
 
 def main() -> None:
